@@ -7,17 +7,17 @@
 ## Creating pipeline stages that operate on column subsets
 
 Many pipeline stages in pdpipe operate on a subset of columns, allowing the
-caller to deteremine this subset by either providing a fixed set of column
+caller to determine this subset by either providing a fixed set of column
 labels or by providing a callable that determines the column subset dynamically
 from input dataframes. The `pdpipe.cq` module addresses a unique but important
-use case of fittable column qualifier, which dynamically extract a column
+use case of fittable column qualifier, which is to dynamically extract a column
 subset on stage fit time, but keep it fixed for future transformations.
 
 As a general rule, every pipeline stage in pdpipe that supports the `columns`
 parameter should inherently support fittable column qualifier, and generally
 the correct interpretation of both single and multiple labels as arguments. To
 unify the implementation of such functionality, and ease of creation of new
-pipeline stages, such columns shoul be created by extending the
+pipeline stages, such columns should be created by extending the
 ColumnsBasedPipelineStage base class, found in this module (`pdpipe.core`).
 
 The main interface of sub-classes of this base class with it is through the
@@ -38,11 +38,11 @@ The main interface of sub-classes of this base class with it is through the
   providing `columns=cq.OfDtype(np.number),
   exclude_columns=cq.OfDtype(np.int64)`. However, exposing the
   `exclude_columns` parameter can allow for specific unique behaviours; for
-  example, if the `none_columns` parametet - which configures the behavior
+  example, if the `none_columns` parameter - which configures the behavior
   when `columns` is provided with `None` - is set with
   a `cq.OfDtypes('category')` column qualifier, which means that all
   categorical columns are selected when `columns=None`, then exposing
-  `exclude_columns` allows easy specification of the "all categorical
+  `exclude_columns` allows for easy specification of the "all categorical
   columns except X" by just giving a column qualifier capturing X to
   `exclude_columns`, instead of having to reconstruct the default column
   qualifier by hand and substract from it the one representing X.
@@ -80,8 +80,8 @@ stage you're creating is inherently fittable or not:
    transforming.
 
 Again, taking a look at the VERY concise implementation of simple columns-based
-stages, like ColDrop or ValDrop, will probably make things clearer, and you can
-use those implementations as a template for yours.
+stages, like ColDrop or ValDrop in `pdpipe.basic_stages`, will probably make
+things clearer, and you can use those implementations as a template for yours.
 """
 
 import sys
@@ -219,7 +219,7 @@ class PdPipelineStage(abc.ABC):
         If true, a pdpipe.FailedPreconditionError is raised when this
         stage is applied to a dataframe for which the precondition does
         not hold. Otherwise the stage is skipped. Additionally, if true, a
-        pdpipe.FailedPostconditionError is raised if an expected post-codnition
+        pdpipe.FailedPostconditionError is raised if an expected post-condition
         does not hold for an output dataframe (after pipeline application).
         Otherwise pipeline application continues uninterrupted.
     exmsg : str, default None
@@ -233,30 +233,30 @@ class PdPipelineStage(abc.ABC):
         This can be assigned a callable that returns boolean values for input
         dataframes, which will be used to determine whether input dataframes
         satisfy the preconditions for this pipeline stage (see the `exraise`
-        parameter for the behaviour of failed preconditions). See pdp.cond for
-        more information on specialised Condition objects.
+        parameter for the behaviour of failed preconditions). See `pdpipe.cond`
+        for more information on specialised Condition objects.
     post : callable, default None
         This can be assigned a callable that returns boolean values for input
         dataframes, which will be used to determine whether input dataframes
         satisfy the postconditions for this pipeline stage (see the `exraise`
-        parameter for the behaviour of failed postconditions). See pdp.cond for
-        more information on specialised Condition objects.
+        parameter for the behaviour of failed postconditions). See
+        `pdpipe.cond` for more information on specialised Condition objects.
     skip : callable, default None
         This can be assigned a callable that returns boolean values for input
         dataframes, which will be used to determine whether this stage should
         be skipped for input dataframes - if the callable returns True for an
-        input dataframe, this stage will be skipped. See pdp.cond for more
+        input dataframe, this stage will be skipped. See `pdpipe.cond` for more
         information on specialised Condition objects.
     name : str, default ''
         The name of this stage. Pipelines can be sliced by this name.
 
     Attributes
     ----------
-    fit_context : PdpApplicationContext
+    fit_context : `PdpApplicationContext`
         An application context object that is only re-initialized before
         `fit_transform` calls, and is locked after pipeline application. It is
         injected into the PipelineStage by the encapsulating pipeline object.
-    application_context : PdpApplicationContext
+    application_context : `PdpApplicationContext`
         An application context object that is re-initialized before every
         pipeline application (so, also during transform operations of fitted
         pipelines), and is locked after pipeline application.It is injected
@@ -325,6 +325,20 @@ class PdPipelineStage(abc.ABC):
             return False
         return True
 
+    def _raise_precondition_error(self):
+        try:
+            raise FailedPreconditionError(
+                f"{self._exmsg} [Reason] {self._prec_arg.error_message}")
+        except AttributeError:
+            raise FailedPreconditionError(self._exmsg)
+
+    def _raise_postcondition_error(self):
+        try:
+            raise FailedPostconditionError(
+                f"{self._exmsg_post} [Reason] {self._post_arg.error_message}")
+        except AttributeError:
+            raise FailedPostconditionError(self._exmsg_post)
+
     @abc.abstractmethod
     def _transform(self, df, verbose):
         """Transforms the given dataframe without fitting this stage."""
@@ -367,10 +381,10 @@ class PdPipelineStage(abc.ABC):
             else:
                 res_df = self._fit_transform(df, verbose=verbose)
             if exraise and not self._compound_post(df=res_df):
-                raise FailedPostconditionError(self._exmsg_post)
+                self._raise_postcondition_error()
             return res_df
         if exraise:
-            raise FailedPreconditionError(self._exmsg)
+            self._raise_precondition_error()
         return df
 
     __call__ = apply
@@ -406,10 +420,10 @@ class PdPipelineStage(abc.ABC):
                 print(msg, flush=True)
             res_df = self._fit_transform(X, verbose=verbose)
             if exraise and not self._compound_post(df=res_df):
-                raise FailedPostconditionError(self._exmsg_post)
+                self._raise_postcondition_error()
             return res_df
         if exraise:
-            raise FailedPreconditionError(self._exmsg)
+            self._raise_precondition_error()
         return X
 
     def fit(self, X, y=None, exraise=None, verbose=False):
@@ -443,10 +457,10 @@ class PdPipelineStage(abc.ABC):
                 print(msg, flush=True)
             res_df = self._fit_transform(X, verbose=verbose)
             if exraise and not self._compound_post(df=res_df):
-                raise FailedPostconditionError(self._exmsg_post)
+                self._raise_postcondition_error()
             return X
         if exraise:
-            raise FailedPreconditionError(self._exmsg)
+            self._raise_precondition_error()
         return X
 
     def transform(self, X, y=None, exraise=None, verbose=False):
@@ -477,7 +491,7 @@ class PdPipelineStage(abc.ABC):
         """
         if exraise is None:
             exraise = self._exraise
-        if self._prec(X):
+        if self._compound_prec(X):
             if verbose:
                 msg = '- ' + '\n  '.join(textwrap.wrap(self._appmsg))
                 print(msg, flush=True)
@@ -485,16 +499,16 @@ class PdPipelineStage(abc.ABC):
                 if self.is_fitted:
                     res_df = self._transform(X, verbose=verbose)
                     if exraise and not self._compound_post(df=res_df):
-                        raise FailedPostconditionError(self._exmsg_post)
+                        self._raise_postcondition_error()
                     return res_df
                 raise UnfittedPipelineStageError(
                     "transform of an unfitted pipeline stage was called!")
             res_df = self._transform(X, verbose=verbose)
             if exraise and not self._compound_post(df=res_df):
-                raise FailedPostconditionError(self._exmsg_post)
+                self._raise_postcondition_error()
             return res_df
         if exraise:
-            raise FailedPreconditionError(self._exmsg)
+            self._raise_precondition_error()
         return X
 
     def __add__(self, other):
@@ -539,15 +553,15 @@ class ColumnsBasedPipelineStage(PdPipelineStage):
 
     Parameters
     ---------
-    columns : object, iterable or callable
+    columns : single label, iterable or callable
         The label, or an iterable of labels, of columns to use. Alternatively,
         this parameter can be assigned a callable returning an iterable of
-        labels from an input pandas.DataFrame. See pdpipe.cq.
-    exclude_columns : object, iterable or callable, optional
+        labels from an input pandas.DataFrame. See `pdpipe.cq`.
+    exclude_columns : single label, iterable or callable, optional
         The label, or an iterable of labels, of columns to exclude, given the
         `columns` parameter. Alternatively, this parameter can be assigned a
         callable returning a labels iterable from an input pandas.DataFrame.
-        See pdpipe.cq. Optional. By default no columns are excluded.
+        See `pdpipe.cq`. Optional. By default no columns are excluded.
     desc_temp : str, optional
         If given, assumed to be a format string, and every appearance of {} in
         it is replaced with an appropriate string representation of the columns
@@ -693,11 +707,12 @@ class AdHocStage(PdPipelineStage):
     specific name is assumed or used) to supply the callable with the pandas
     DataFrame object to transform. The following additional keyword arguments
     are supplied if the are included in the callable's signature:
-    `verbose` - Passed on from pdpipe's `fit`, `fit_transform`
+    `verbose` - Passed on from PdPipelineStage's `fit`, `fit_transform`
     and `apply` methods.
+
     `fit_context` and `application_context` - Provides fit-specific and
-    application-specific contexts, in the form of PdpApplicationContext
-    objects, usually available to pipeline stages using `self.fit_context` and
+    application-specific contexts (see `PdpApplicationContext`) usually
+    available to pipeline stages using `self.fit_context` and
     `self.application_context`.
 
     Parameters
@@ -714,6 +729,19 @@ class AdHocStage(PdPipelineStage):
         A callable that returns a boolean value. Represent a a precondition
         used to determine whether this stage can be applied to a given
         dataframe. If None is given, set to a function always returning True.
+
+    Example
+    -------
+        >>> import pandas as pd; import pdpipe as pdp;
+        >>> df = pd.DataFrame([[1, 'a'], [2, 'b']], [1, 2], ['num', 'char'])
+        >>> drop_num = pdp.AdHocStage(
+        ...   transform=lambda df: df.drop(['num'], axis=1),
+        ...   prec=lambda df: 'num' in df.columns
+        ... )
+        >>> drop_num.apply(df)
+          char
+        1    a
+        2    b
     """
 
     def __init__(self, transform, fit_transform=None, prec=None, **kwargs):
@@ -761,7 +789,7 @@ class AdHocStage(PdPipelineStage):
 class PdPipeline(PdPipelineStage, collections.abc.Sequence):
     """A pipeline for processing pandas DataFrame objects.
 
-    transformer_getter is usefull to avoid applying pipeline stages that are
+    `transformer_getter` is useful to avoid applying pipeline stages that are
     aimed to filter out items in a big dataset to create a training set for a
     machine learning model, for example, but should not be applied on future
     individual items to be transformed by the fitted pipeline.
@@ -827,14 +855,53 @@ class PdPipeline(PdPipelineStage, collections.abc.Sequence):
         self.application_context.lock()
         self.fit_context.lock()
 
-    def apply(self, df, exraise=None, verbose=False):
+    def apply(self, df, exraise=None, verbose=False, time=False):
+        """Applies this pipeline stage to the given dataframe.
+
+        If the stage is not fitted fit_transform is called. Otherwise,
+        transform is called.
+
+        Parameters
+        ----------
+        df : pandas.DataFrame
+            The dataframe to which this pipeline stage will be applied.
+        exraise : bool, default None
+            Determines behaviour if the precondition of composing stages is not
+            fulfilled by the input dataframe: If True, a
+            pdpipe.FailedPreconditionError is raised. If False, the stage is
+            skipped. If not given, or set to None, the default behaviour of
+            each stage is used, as determined by its 'exraise' constructor
+            parameter.
+        verbose : bool, default False
+            If True an explanation message is printed after the precondition
+            is checked but before the application of the pipeline stage.
+            Defaults to False.
+        time : bool, default False
+            If True, per-stage application time is measured and reported when
+            pipeline application is done.
+
+        Returns
+        -------
+        pandas.DataFrame
+            The resulting dataframe.
+        """
         self.application_context = PdpApplicationContext()
         if self.is_fitted:
-            res = self.transform(X=df, exraise=exraise, verbose=verbose)
+            res = self.transform(
+                X=df,
+                exraise=exraise,
+                verbose=verbose,
+                time=time
+            )
             self._post_transform_lock()
             return res
         self.fit_context = PdpApplicationContext()
-        res = self.fit_transform(X=df, exraise=exraise, verbose=verbose)
+        res = self.fit_transform(
+            X=df,
+            exraise=exraise,
+            verbose=verbose,
+            time=time
+        )
         self._post_transform_lock()
         return res
 
@@ -895,7 +962,7 @@ class PdPipeline(PdPipelineStage, collections.abc.Sequence):
         Returns
         -------
         pandas.DataFrame
-            The resulting dacaframe.
+            The resulting dataframe.
         """
         if time:
             return self.__timed_fit_transform(
@@ -1166,7 +1233,7 @@ def make_pdpipeline(*stages):
 
     Examples
     --------
-    import pdpipe as pdp
-    make_pdpipeline(pdp.ColDrop('a'), pdp.Bin('speed'))
+        >>> import pdpipe as pdp
+        >>> p = make_pdpipeline(pdp.ColDrop('count'), pdp.DropDuplicates())
     """
     return PdPipeline(stages=stages)
